==> symfony_6.4.5+dfsg.orig.tar.xz: symfony-6.4.5/src/Symfony/Component/Intl/Resources/data/locales/fa_AF.php <==
<?php

return [
    'Names' => [
        'ak_GH' => 'آکان (گانا)',
        'am_ET' => 'امهری (ایتوپیا)',
        'ar_ER' => 'عربی (اریتریا)',
        'ar_LY' => 'عربی (لیبیا)',
        'ar_MR' => 'عربی (موریتانیا)',
        'ar_SO' => 'عربی (سومالیه)',
        'as' => 'اسامی',
        'as_IN' => 'اسامی (هند)',
        'az' => 'آذربایجانی',
        'az_AZ' => 'آذربایجانی (جمهوری آذربایجان)',
        'az_Cyrl' => 'آذربایجانی (سیریلی)',
        'az_Cyrl_AZ' => 'آذربایجانی (سیریلی، جمهوری آذربایجان)',
        'az_Latn' => 'آذربایجانی (لاتین)',
        'az_Latn_AZ' => 'آذربایجانی (لاتین، جمهوری آذربایجان)',
        'bg_BG' => 'بلغاری (بلغاریا)',
        'bn_BD' => 'بنگالی (بنگله‌دیش)',
        'bs_BA' => 'بوسنیایی (بوسنیا و هرزه‌گوینا)',
        'bs_Cyrl_BA' => 'بوسنیایی (سیریلی، بوسنیا و هرزه‌گوینا)',
        'bs_Latn_BA' => 'بوسنیایی (لاتین، بوسنیا و هرزه‌گوینا)',
        'ca_AD' => 'کاتالان (اندورا)',
        'ca_ES' => 'کاتالان (هسپانیه)',
        'da_DK' => 'دانمارکی (دنمارک)',
        'de_BE' => 'آلمانی (بلجیم)',
        'de_CH' => 'آلمانی (سویس)',
        'ee_GH' => 'اوه‌ای (گانا)',
        'en_AG' => 'انگلیسی (انتیگوا و باربودا)',
        'en_BE' => 'انگلیسی (بلجیم)',
        'en_BS' => 'انگلیسی (بهاماس)',
        'en_CH' => 'انگلیسی (سویس)',
        'en_DK' => 'انگلیسی (دنمارک)',
        'en_ER' => 'انگلیسی (اریتریا)',
        'en_FI' => 'انگلیسی (فنلند)',
        'en_FM' => 'انگلیسی (میکرونزیا)',
        'en_GD' => 'انگلیسی (گرینادا)',
        'en_GH' => 'انگلیسی (گانا)',
        'en_GY' => 'انگلیسی (گیانا)',
        'en_HK' => 'انگلیسی (هانگ کانگ، ناحیهٔ ویژهٔ حکومتی چین)',
        'en_ID' => 'انگلیسی (اندونیزیا)',
        'en_IE' => 'انگلیسی (آیرلند)',
        'en_KE' => 'انگلیسی (کینیا)',
        'en_LS' => 'انگلیسی (لیسوتو)',
        'en_MG' => 'انگلیسی (مادغاسکر)',
        'en_MT' => 'انگلیسی (مالتا)',
        'en_MY' => 'انگلیسی (مالیزیا)',
        'en_NG' => 'انگلیسی (نیجریا)',
        'en_NL' => 'انگلیسی (هالند)',
        'en_NZ' => 'انگلیسی (زیلاند جدید)',
        'en_PG' => 'انگلیسی (پاپوا نیو گینیا)',
        'en_SE' => 'انگلیسی (سویدن)',
        'en_SG' => 'انگلیسی (سینگاپور)',
        'en_SI' => 'انگلیسی (سلونیا)',
        'en_SL' => 'انگلیسی (سیرالیون)',
        'en_UG' => 'انگلیسی (یوگاندا)',
        'en_VC' => 'انگلیسی (سنت وینسنت و گرنادین‌ها)',
        'en_ZW' => 'انگلیسی (زیمبابوی)',
        'es' => 'هسپانوی',
        'es_419' => 'هسپانوی (امریکای لاتین)',
        'es_AR' => 'هسپانوی (ارجنتاین)',
        'es_BO' => 'هسپانوی (بولیویا)',
        'es_BR' => 'هسپانوی (برازیل)',
        'es_BZ' => 'هسپانوی (بلیز)',
        'es_CL' => 'هسپانوی (چلی)',
        'es_CO' => 'هسپانوی (کولمبیا)',
        'es_CR' => 'هسپانوی (کاستریکا)',
        'es_CU' => 'هسپانوی (کیوبا)',
        'es_DO' => 'هسپانوی (جمهوری دومینیکن)',
        'es_EC' => 'هسپانوی (اکوادور)',
        'es_ES' => 'هسپانوی (هسپانیه)',
        'es_GQ' => 'هسپانوی (گینیا استوایی)',
        'es_GT' => 'هسپانوی (گواتیمالا)',
        'es_HN' => 'هسپانوی (هاندوراس)',
        'es_MX' => 'هسپانوی (مکسیکو)',
        'es_NI' => 'هسپانوی (نیکاراگوا)',
        'es_PA' => 'هسپانوی (پانامه)',
        'es_PE' => 'هسپانوی (پیرو)',
        'es_PH' => 'هسپانوی (فیلیپین)',
        'es_PR' => 'هسپانوی (پورتوریکو)',
        'es_PY' => 'هسپانوی (پاراگوای)',
        'es_SV' => 'هسپانوی (السلوادور)',
        'es_US' => 'هسپانوی (ایالات متحده)',
        'es_UY' => 'هسپانوی (یوروگوای)',
        'es_VE' => 'هسپانوی (ونزویلا)',
        'et_EE' => 'استونیایی (استونیا)',
        'eu_ES' => 'باسکی (هسپانیه)',
        'ff_Adlm_GH' => 'فولانی (آدلام، گانا)',
        'ff_Adlm_GN' => 'فولانی (آدلام، گینیا)',
        'ff_Adlm_GW' => 'فولانی (آدلام، گینیا بیسائو)',
        'ff_Adlm_MR' => 'فولانی (آدلام، موریتانیا)',
        'ff_Adlm_NG' => 'فولانی (آدلام، نیجریا)',
        'ff_Adlm_SL' => 'فولانی (آدلام، سیرالیون)',
        'ff_Adlm_SN' => 'فولانی (آدلام، سینیگال)',
        'ff_GN' => 'فولانی (گینیا)',
        'ff_Latn_GH' => 'فولانی (لاتین، گانا)',
        'ff_Latn_GN' => 'فولانی (لاتین، گینیا)',
        'ff_Latn_GW' => 'فولانی (لاتین، گینیا بیسائو)',
        'ff_Latn_MR' => 'فولانی (لاتین، موریتانیا)',
        'ff_Latn_NG' => 'فولانی (لاتین، نیجریا)',
        'ff_Latn_SL' => 'فولانی (لاتین، سیرالیون)',
        'ff_Latn_SN' => 'فولانی (لاتین، سینیگال)',
        'ff_MR' => 'فولانی (موریتانیا)',
        'ff_SN' => 'فولانی (سینیگال)',
        'fi' => 'فنلندی',
        'fi_FI' => 'فنلندی (فنلند)',
        'fo_DK' => 'فارویی (دنمارک)',
        'fr_BE' => 'فرانسوی (بلجیم)',
        'fr_CD' => 'فرانسوی (کانگو - کینشاسا)',
        'fr_CG' => 'فرانسوی (کانگو - برازویل)',
        'fr_CH' => 'فرانسوی (سویس)',
        'fr_GN' => 'فرانسوی (گینیا)',
        'fr_GQ' => 'فرانسوی (گینیا استوایی)',
        'fr_HT' => 'فرانسوی (هایتی)',
        'fr_MG' => 'فرانسوی (مادغاسکر)',
        'fr_MR' => 'فرانسوی (موریتانیا)',
        'fr_SN' => 'فرانسوی (سینیگال)',
        'fy_NL' => 'فریسی غربی (هالند)',
        'ga' => 'آیرلندی',
        'ga_GB' => 'آیرلندی (بریتانیا)',
        'ga_IE' => 'آیرلندی (آیرلند)',
        'gl_ES' => 'گالیسیایی (هسپانیه)',
        'ha_GH' => 'هوسایی (گانا)',
        'ha_NG' => 'هوسایی (نیجریا)',
        'hr' => 'کروشیایی',
        'hr_BA' => 'کروشیایی (بوسنیا و هرزه‌گوینا)',
        'hr_HR' => 'کروشیایی (کروشیا)',
        'id' => 'اندونیزیایی',
        'id_ID' => 'اندونیزیایی (اندونیزیا)',
        'ie_EE' => 'اکسیدنتال (استونیا)',
        'ig_NG' => 'ایگبویی (نیجریا)',
        'is' => 'آیسلندی',
        'is_IS' => 'آیسلندی (آیسلند)',
        'it' => 'ایتالوی',
        'it_CH' => 'ایتالوی (سویس)',
        'it_IT' => 'ایتالوی (ایتالیا)',
        'it_SM' => 'ایتالوی (سان‌مارینو)',
        'it_VA' => 'ایتالوی (واتیکان)',
        'ja' => 'جاپانی',
        'ja_JP' => 'جاپانی (جاپان)',
        'jv_ID' => 'جاوه‌ای (اندونیزیا)',
        'ki_KE' => 'کیکویویی (کینیا)',
        'km_KH' => 'خمری (کمپوچیا)',
        'ko' => 'کوریایی',
        'ko_CN' => 'کوریایی (چین)',
        'ko_KP' => 'کوریایی (کوریای شمالی)',
        'ko_KR' => 'کوریایی (کوریای جنوبی)',
        'ky' => 'قرغزی',
        'ky_KG' => 'قرغزی (قرقیزستان)',
        'lg_UG' => 'گاندایی (یوگاندا)',
        'ln_AO' => 'لینگالا (انگولا)',
        'ln_CD' => 'لینگالا (کانگو - کینشاسا)',
        'ln_CG' => 'لینگالا (کانگو - برازویل)',
        'lt_LT' => 'لیتوانیایی (لتوانیا)',
        'lu_CD' => 'لوبایی‐کاتانگا (کانگو - کینشاسا)',
        'lv_LV' => 'لتونیایی (لاتویا)',
        'mg_MG' => 'مالاگاسی (مادغاسکر)',
        'mi_NZ' => 'مائوری (زیلاند جدید)',
        'mn' => 'مغلی',
        'mn_MN' => 'مغلی (منگولیا)',
        'ms_BN' => 'مالایی (برونی)',
        'ms_ID' => 'مالایی (اندونیزیا)',
        'ms_MY' => 'مالایی (مالیزیا)',
        'ms_SG' => 'مالایی (سینگاپور)',
        'mt_MT' => 'مالتی (مالتا)',
        'nb' => 'نروژی کتابی',
        'nb_NO' => 'نروژی کتابی (ناروی)',
        'nb_SJ' => 'نروژی کتابی (اسوالبارد و جان ماین)',
        'nd_ZW' => 'انده‌بله‌ای شمالی (زیمبابوی)',
        'ne' => 'نیپالی',
        'ne_IN' => 'نیپالی (هند)',
        'ne_NP' => 'نیپالی (نیپال)',
        'nl' => 'هالندی',
        'nl_AW' => 'هالندی (آروبا)',
        'nl_BE' => 'هالندی (بلجیم)',
        'nl_BQ' => 'هالندی (جزایر کارائیب هلند)',
        'nl_CW' => 'هالندی (کوراسائو)',
        'nl_NL' => 'هالندی (هالند)',
        'nl_SR' => 'هالندی (سورینام)',
        'nl_SX' => 'هالندی (سنت مارتن)',
        'nn' => 'نروژی نو',
        'nn_NO' => 'نروژی نو (ناروی)',
        'no' => 'نارویژی',
        'no_NO' => 'نارویژی (ناروی)',
        'oc_ES' => 'اکسیتان (هسپانیه)',
        'om_ET' => 'اورومویی (ایتوپیا)',
        'om_KE' => 'اورومویی (کینیا)',
        'pl' => 'پولندی',
        'pl_PL' => 'پولندی (پولند)',
        'pt' => 'پرتگالی',
        'pt_AO' => 'پرتگالی (انگولا)',
        'pt_BR' => 'پرتگالی (برازیل)',
        'pt_CH' => 'پرتگالی (سویس)',
        'pt_CV' => 'پرتگالی (کیپ‌ورد)',
        'pt_GQ' => 'پرتگالی (گینیا استوایی)',
        'pt_GW' => 'پرتگالی (گینیا بیسائو)',
        'pt_LU' => 'پرتگالی (لوکزامبورگ)',
        'pt_MO' => 'پرتگالی (ماکائو، منطقهٔ ویژهٔ اداری چین)',
        'pt_MZ' => 'پرتگالی (موزمبیق)',
        'pt_PT' => 'پرتگالی (پرتگال)',
        'pt_ST' => 'پرتگالی (سائوتومه و پرینسیپ)',
        'pt_TL' => 'پرتگالی (تیمور-لسته)',
        'qu_BO' => 'کچوایی (بولیویا)',
        'qu_PE' => 'کچوایی (پیرو)',
        'rm_CH' => 'رومانش (سویس)',
        'ro_RO' => 'رومانیایی (رومانیا)',
        'se_FI' => 'سامی شمالی (فنلند)',
        'se_NO' => 'سامی شمالی (ناروی)',
        'se_SE' => 'سامی شمالی (سویدن)',
        'sh_BA' => 'صرب و کرواتی (بوسنیا و هرزه‌گوینا)',
        'si_LK' => 'سینهالی (سریلانکا)',
        'sk_SK' => 'اسلواکی (سلواکیا)',
        'sl_SI' => 'اسلوونیایی (سلونیا)',
        'sn_ZW' => 'شونایی (زیمبابوی)',
        'so_ET' => 'سومالیایی (ایتوپیا)',
        'so_KE' => 'سومالیایی (کینیا)',
        'so_SO' => 'سومالیایی (سومالیه)',
        'sq' => 'البانیایی',
        'sq_AL' => 'البانیایی (البانیا)',
        'sq_MK' => 'البانیایی (مقدونیهٔ شمالی)',
        'sr_BA' => 'صربی (بوسنیا و هرزه‌گوینا)',
        'sr_Cyrl_BA' => 'صربی (سیریلی، بوسنیا و هرزه‌گوینا)',
        'sr_Latn_BA' => 'صربی (لاتین، بوسنیا و هرزه‌گوینا)',
        'su_ID' => 'سوندایی (اندونیزیا)',
        'su_Latn_ID' => 'سوندایی (لاتین، اندونیزیا)',
        'sv' => 'سویدنی',
        'sv_AX' => 'سویدنی (جزایر آلاند)',
        'sv_FI' => 'سویدنی (فنلند)',
        'sv_SE' => 'سویدنی (سویدن)',
        'sw' => 'سواحلی',
        'sw_CD' => 'سواحلی (کانگو - کینشاسا)',
        'sw_KE' => 'سواحلی (کینیا)',
        'sw_TZ' => 'سواحلی (تانزانیا)',
        'sw_UG' => 'سواحلی (یوگاندا)',
        'ta_LK' => 'تامیلی (سریلانکا)',
        'ta_MY' => 'تامیلی (مالیزیا)',
        'ta_SG' => 'تامیلی (سینگاپور)',
        'tg' => 'تاجکی',
        'tg_TJ' => 'تاجکی (تاجکستان)',
        'ti_ER' => 'تیگرینیایی (اریتریا)',
        'ti_ET' => 'تیگرینیایی (ایتوپیا)',
        'wo_SN' => 'ولوفی (سینیگال)',
        'yo_NG' => 'یوروبایی (نیجریا)',
        'zh_HK' => 'چینی (هانگ کانگ، ناحیهٔ ویژهٔ حکومتی چین)',
        'zh_Hans_HK' => 'چینی (ساده‌شده، هانگ کانگ، ناحیهٔ ویژهٔ حکومتی چین)',
        'zh_Hans_SG' => 'چینی (ساده‌شده، سینگاپور)',
        'zh_Hant_HK' => 'چینی (سنتی، هانگ کانگ، ناحیهٔ ویژهٔ حکومتی چین)',
        'zh_SG' => 'چینی (سینگاپور)',
    ],
];

==> symfony_6.4.25+dfsg.orig.tar.xz: symfony-6.4.25/src/Symfony/Component/Intl/Resources/data/locales/fa_AF.php <==
<?php

return [
    'Names' => [
        'ak_GH' => 'آکان (گانا)',
        'am_ET' => 'امهری (ایتوپیا)',
        'ar_ER' => 'عربی (اریتریا)',
        'ar_LY' => 'عربی (لیبیا)',
        'ar_MR' => 'عربی (موریتانیا)',
        'ar_SO' => 'عربی (سومالیه)',
        'as' => 'اسامی',
        'as_IN' => 'اسامی (هند)',
        'az' => 'آذربایجانی',
        'az_AZ' => 'آذربایجانی (جمهوری آذربایجان)',
        'az_Cyrl' => 'آذربایجانی (سیریلی)',
        'az_Cyrl_AZ' => 'آذربایجانی (سیریلی، جمهوری آذربایجان)',
        'az_Latn' => 'آذربایجانی (لاتین)',
        'az_Latn_AZ' => 'آذربایجانی (لاتین، جمهوری آذربایجان)',
        'bg_BG' => 'بلغاری (بلغاریا)',
        'bn_BD' => 'بنگالی (بنگله‌دیش)',
        'bs_BA' => 'بوسنیایی (بوسنیا و هرزه‌گوینا)',
        'bs_Cyrl_BA' => 'بوسنیایی (سیریلی، بوسنیا و هرزه‌گوینا)',
        'bs_Latn_BA' => 'بوسنیایی (لاتین، بوسنیا و هرزه‌گوینا)',
        'ca_AD' => 'کاتالان (اندورا)',
        'ca_ES' => 'کاتالان (هسپانیه)',
        'da_DK' => 'دانمارکی (دنمارک)',
        'de_BE' => 'آلمانی (بلجیم)',
        'de_CH' => 'آلمانی (سویس)',
        'ee_GH' => 'اوه‌ای (گانا)',
        'en_AG' => 'انگلیسی (انتیگوا و باربودا)',
        'en_BE' => 'انگلیسی (بلجیم)',
        'en_BS' => 'انگلیسی (بهاماس)',
        'en_CH' => 'انگلیسی (سویس)',
        'en_DK' => 'انگلیسی (دنمارک)',
        'en_ER' => 'انگلیسی (اریتریا)',
        'en_ES' => 'انگلیسی (هسپانیه)',
        'en_FI' => 'انگلیسی (فنلند)',
        'en_FM' => 'انگلیسی (میکرونزیا)',
        'en_GD' => 'انگلیسی (گرینادا)',
        'en_GH' => 'انگلیسی (گانا)',
        'en_GY' => 'انگلیسی (گیانا)',
        'en_HK' => 'انگلیسی (هانگ کانگ، ناحیهٔ ویژهٔ حکومتی چین)',
        'en_ID' => 'انگلیسی (اندونیزیا)',
        'en_IE' => 'انگلیسی (آیرلند)',
        'en_KE' => 'انگلیسی (کینیا)',
        'en_LS' => 'انگلیسی (لیسوتو)',
        'en_MG' => 'انگلیسی (مادغاسکر)',
        'en_MT' => 'انگلیسی (مالتا)',
        'en_MY' => 'انگلیسی (مالیزیا)',
        'en_NG' => 'انگلیسی (نیجریا)',
        'en_NL' => 'انگلیسی (هالند)',
        'en_NO' => 'انگلیسی (ناروی)',
        'en_NZ' => 'انگلیسی (زیلاند جدید)',
        'en_PG' => 'انگلیسی (پاپوا نیو گینیا)',
        'en_PL' => 'انگلیسی (پولند)',
        'en_PT' => 'انگلیسی (پرتگال)',
        'en_RO' => 'انگلیسی (رومانیا)',
        'en_SE' => 'انگلیسی (سویدن)',
        'en_SG' => 'انگلیسی (سینگاپور)',
        'en_SI' => 'انگلیسی (سلونیا)',
        'en_SK' => 'انگلیسی (سلواکیا)',
        'en_SL' => 'انگلیسی (سیرالیون)',
        'en_UG' => 'انگلیسی (یوگاندا)',
        'en_VC' => 'انگلیسی (سنت وینسنت و گرنادین‌ها)',
        'en_ZW' => 'انگلیسی (زیمبابوی)',
        'es' => 'هسپانوی',
        'es_419' => 'هسپانوی (امریکای لاتین)',
        'es_AR' => 'هسپانوی (ارجنتاین)',
        'es_BO' => 'هسپانوی (بولیویا)',
        'es_BR' => 'هسپانوی (برازیل)',
        'es_BZ' => 'هسپانوی (بلیز)',
        'es_CL' => 'هسپانوی (چلی)',
        'es_CO' => 'هسپانوی (کولمبیا)',
        'es_CR' => 'هسپانوی (کاستریکا)',
        'es_CU' => 'هسپانوی (کیوبا)',
        'es_DO' => 'هسپانوی (جمهوری دومینیکن)',
        'es_EC' => 'هسپانوی (اکوادور)',
        'es_ES' => 'هسپانوی (هسپانیه)',
        'es_GQ' => 'هسپانوی (گینیا استوایی)',
        'es_GT' => 'هسپانوی (گواتیمالا)',
        'es_HN' => 'هسپانوی (هاندوراس)',
        'es_MX' => 'هسپانوی (مکسیکو)',
        'es_NI' => 'هسپانوی (نیکاراگوا)',
        'es_PA' => 'هسپانوی (پانامه)',
        'es_PE' => 'هسپانوی (پیرو)',
        'es_PH' => 'هسپانوی (فیلیپین)',
        'es_PR' => 'هسپانوی (پورتوریکو)',
        'es_PY' => 'هسپانوی (پاراگوای)',
        'es_SV' => 'هسپانوی (السلوادور)',
        'es_US' => 'هسپانوی (ایالات متحده)',
        'es_UY' => 'هسپانوی (یوروگوای)',
        'es_VE' => 'هسپانوی (ونزویلا)',
        'et_EE' => 'استونیایی (استونیا)',
        'eu_ES' => 'باسکی (هسپانیه)',
        'ff_Adlm_GH' => 'فولانی (آدلام، گانا)',
        'ff_Adlm_GN' => 'فولانی (آدلام، گینیا)',
        'ff_Adlm_GW' => 'فولانی (آدلام، گینیا بیسائو)',
        'ff_Adlm_MR' => 'فولانی (آدلام، موریتانیا)',
        'ff_Adlm_NG' => 'فولانی (آدلام، نیجریا)',
        'ff_Adlm_SL' => 'فولانی (آدلام، سیرالیون)',
        'ff_Adlm_SN' => 'فولانی (آدلام، سینیگال)',
        'ff_GN' => 'فولانی (گینیا)',
        'ff_Latn_GH' => 'فولانی (لاتین، گانا)',
        'ff_Latn_GN' => 'فولانی (لاتین، گینیا)',
        'ff_Latn_GW' => 'فولانی (لاتین، گینیا بیسائو)',
        'ff_Latn_MR' => 'فولانی (لاتین، موریتانیا)',
        'ff_Latn_NG' => 'فولانی (لاتین، نیجریا)',
        'ff_Latn_SL' => 'فولانی (لاتین، سیرالیون)',
        'ff_Latn_SN' => 'فولانی (لاتین، سینیگال)',
        'ff_MR' => 'فولانی (موریتانیا)',
        'ff_SN' => 'فولانی (سینیگال)',
        'fi' => 'فنلندی',
        'fi_FI' => 'فنلندی (فنلند)',
        'fo_DK' => 'فارویی (دنمارک)',
        'fr_BE' => 'فرانسوی (بلجیم)',
        'fr_CD' => 'فرانسوی (کانگو - کینشاسا)',
        'fr_CG' => 'فرانسوی (کانگو - برازویل)',
        'fr_CH' => 'فرانسوی (سویس)',
        'fr_GN' => 'فرانسوی (گینیا)',
        'fr_GQ' => 'فرانسوی (گینیا استوایی)',
        'fr_HT' => 'فرانسوی (هایتی)',
        'fr_MG' => 'فرانسوی (مادغاسکر)',
        'fr_MR' => 'فرانسوی (موریتانیا)',
        'fr_SN' => 'فرانسوی (سینیگال)',
        'fy_NL' => 'فریسی غربی (هالند)',
        'ga' => 'آیرلندی',
        'ga_GB' => 'آیرلندی (بریتانیا)',
        'ga_IE' => 'آیرلندی (آیرلند)',
        'gl_ES' => 'گالیسیایی (هسپانیه)',
        'ha_GH' => 'هوسایی (گانا)',
        'ha_NG' => 'هوسایی (نیجریا)',
        'hr' => 'کروشیایی',
        'hr_BA' => 'کروشیایی (بوسنیا و هرزه‌گوینا)',
        'hr_HR' => 'کروشیایی (کروشیا)',
        'id' => 'اندونیزیایی',
        'id_ID' => 'اندونیزیایی (اندونیزیا)',
        'ie_EE' => 'اکسیدنتال (استونیا)',
        'ig_NG' => 'ایگبویی (نیجریا)',
        'is' => 'آیسلندی',
        'is_IS' => 'آیسلندی (آیسلند)',
        'it' => 'ایتالوی',
        'it_CH' => 'ایتالوی (سویس)',
        'it_IT' => 'ایتالوی (ایتالیا)',
        'it_SM' => 'ایتالوی (سان‌مارینو)',
        'it_VA' => 'ایتالوی (واتیکان)',
        'ja' => 'جاپانی',
        'ja_JP' => 'جاپانی (جاپان)',
        'jv_ID' => 'جاوه‌ای (اندونیزیا)',
        'ki_KE' => 'کیکویویی (کینیا)',
        'km_KH' => 'خمری (کمپوچیا)',
        'ko' => 'کوریایی',
        'ko_CN' => 'کوریایی (چین)',
        'ko_KP' => 'کوریایی (کوریای شمالی)',
        'ko_KR' => 'کوریایی (کوریای جنوبی)',
        'ky' => 'قرغزی',
        'ky_KG' => 'قرغزی (قرقیزستان)',
        'lg_UG' => 'گاندایی (یوگاندا)',
        'ln_AO' => 'لینگالا (انگولا)',
        'ln_CD' => 'لینگالا (کانگو - کینشاسا)',
        'ln_CG' => 'لینگالا (کانگو - برازویل)',
        'lt_LT' => 'لیتوانیایی (لتوانیا)',
        'lu_CD' => 'لوبایی‐کاتانگا (کانگو - کینشاسا)',
        'lv_LV' => 'لتونیایی (لاتویا)',
        'mg_MG' => 'مالاگاسی (مادغاسکر)',
        'mi_NZ' => 'مائوری (زیلاند جدید)',
        'mn' => 'مغلی',
        'mn_MN' => 'مغلی (منگولیا)',
        'ms_BN' => 'مالایی (برونی)',
        'ms_ID' => 'مالایی (اندونیزیا)',
        'ms_MY' => 'مالایی (مالیزیا)',
        'ms_SG' => 'مالایی (سینگاپور)',
        'mt_MT' => 'مالتی (مالتا)',
        'nb' => 'نروژی کتابی',
        'nb_NO' => 'نروژی کتابی (ناروی)',
        'nb_SJ' => 'نروژی کتابی (اسوالبارد و جان ماین)',
        'nd_ZW' => 'انده‌بله‌ای شمالی (زیمبابوی)',
        'ne' => 'نیپالی',
        'ne_IN' => 'نیپالی (هند)',
        'ne_NP' => 'نیپالی (نیپال)',
        'nl' => 'هالندی',
        'nl_AW' => 'هالندی (آروبا)',
        'nl_BE' => 'هالندی (بلجیم)',
        'nl_BQ' => 'هالندی (جزایر کارائیب هلند)',
        'nl_CW' => 'هالندی (کوراسائو)',
        'nl_NL' => 'هالندی (هالند)',
        'nl_SR' => 'هالندی (سورینام)',
        'nl_SX' => 'هالندی (سنت مارتن)',
        'nn' => 'نروژی نو',
        'nn_NO' => 'نروژی نو (ناروی)',
        'no' => 'نارویژی',
        'no_NO' => 'نارویژی (ناروی)',
        'oc_ES' => 'اکسیتان (هسپانیه)',
        'om_ET' => 'اورومویی (ایتوپیا)',
        'om_KE' => 'اورومویی (کینیا)',
        'pl' => 'پولندی',
        'pl_PL' => 'پولندی (پولند)',
        'pt' => 'پرتگالی',
        'pt_AO' => 'پرتگالی (انگولا)',
        'pt_BR' => 'پرتگالی (برازیل)',
        'pt_CH' => 'پرتگالی (سویس)',
        'pt_CV' => 'پرتگالی (کیپ‌ورد)',
        'pt_GQ' => 'پرتگالی (گینیا استوایی)',
        'pt_GW' => 'پرتگالی (گینیا بیسائو)',
        'pt_LU' => 'پرتگالی (لوکزامبورگ)',
        'pt_MO' => 'پرتگالی (ماکائو، منطقهٔ ویژهٔ اداری چین)',
        'pt_MZ' => 'پرتگالی (موزمبیق)',
        'pt_PT' => 'پرتگالی (پرتگال)',
        'pt_ST' => 'پرتگالی (سائوتومه و پرینسیپ)',
        'pt_TL' => 'پرتگالی (تیمور-لسته)',
        'qu_BO' => 'کچوایی (بولیویا)',
        'qu_PE' => 'کچوایی (پیرو)',
        'rm_CH' => 'رومانش (سویس)',
        'ro_RO' => 'رومانیایی (رومانیا)',
        'se_FI' => 'سامی شمالی (فنلند)',
        'se_NO' => 'سامی شمالی (ناروی)',
        'se_SE' => 'سامی شمالی (سویدن)',
        'sh_BA' => 'صرب و کرواتی (بوسنیا و هرزه‌گوینا)',
        'si_LK' => 'سینهالی (سریلانکا)',
        'sk_SK' => 'اسلواکی (سلواکیا)',
        'sl_SI' => 'اسلوونیایی (سلونیا)',
        'sn_ZW' => 'شونایی (زیمبابوی)',
        'so_ET' => 'سومالیایی (ایتوپیا)',
        'so_KE' => 'سومالیایی (کینیا)',
        'so_SO' => 'سومالیایی (سومالیه)',
        'sq' => 'البانیایی',
        'sq_AL' => 'البانیایی (البانیا)',
        'sq_MK' => 'البانیایی (مقدونیهٔ شمالی)',
        'sr_BA' => 'صربی (بوسنیا و هرزه‌گوینا)',
        'sr_Cyrl_BA' => 'صربی (سیریلی، بوسنیا و هرزه‌گوینا)',
        'sr_Latn_BA' => 'صربی (لاتین، بوسنیا و هرزه‌گوینا)',
        'st_LS' => 'سوتوی جنوبی (لیسوتو)',
        'su_ID' => 'سوندایی (اندونیزیا)',
        'su_Latn_ID' => 'سوندایی (لاتین، اندونیزیا)',
        'sv' => 'سویدنی',
        'sv_AX' => 'سویدنی (جزایر آلاند)',
        'sv_FI' => 'سویدنی (فنلند)',
        'sv_SE' => 'سویدنی (سویدن)',
        'sw' => 'سواحلی',
        'sw_CD' => 'سواحلی (کانگو - کینشاسا)',
        'sw_KE' => 'سواحلی (کینیا)',
        'sw_TZ' => 'سواحلی (تانزانیا)',
        'sw_UG' => 'سواحلی (یوگاندا)',
        'ta_LK' => 'تامیلی (سریلانکا)',
        'ta_MY' => 'تامیلی (مالیزیا)',
        'ta_SG' => 'تامیلی (سینگاپور)',
        'tg' => 'تاجکی',
        'tg_TJ' => 'تاجکی (تاجکستان)',
        'ti_ER' => 'تیگرینیایی (اریتریا)',
        'ti_ET' => 'تیگرینیایی (ایتوپیا)',
        'wo_SN' => 'ولوفی (سینیگال)',
        'yo_NG' => 'یوروبایی (نیجریا)',
        'zh_HK' => 'چینی (هانگ کانگ، ناحیهٔ ویژهٔ حکومتی چین)',
        'zh_Hans_HK' => 'چینی (ساده‌شده، هانگ کانگ، ناحیهٔ ویژهٔ حکومتی چین)',
        'zh_Hans_MY' => 'چینی (ساده‌شده، مالیزیا)',
        'zh_Hans_SG' => 'چینی (ساده‌شده، سینگاپور)',
        'zh_Hant_HK' => 'چینی (سنتی، هانگ کانگ، ناحیهٔ ویژهٔ حکومتی چین)',
        'zh_Hant_MY' => 'چینی (سنتی، مالیزیا)',
        'zh_SG' => 'چینی (سینگاپور)',
    ],
];
